@@ -431,7 +431,7 @@ value.Future <- function(future, stdout = TRUE, signal = TRUE, ...) {
   }
   if (length(conditions) > 0) {
     if (signal) {
-      mdebug("Future state: %s", sQuote(future$state))
+      mdebugf("Future state: %s", sQuote(future$state))
       resignalConditions(future) ## Will signal an (eval) error, iff exists
     } else {
       ## Return 'error' object, iff exists, otherwise NULL
@@ -539,7 +539,7 @@ getExpression.Future <- function(future, local = future$local, stdout = future$s
   
   ## Should 'mc.cores' be set?
   if (!is.null(mc.cores)) {
-##    mdebug("getExpression(): setting mc.cores = %d inside future", mc.cores)
+##    mdebugf("getExpression(): setting mc.cores = %d inside future", mc.cores)
     ## FIXME: How can we guarantee that '...future.mc.cores.old'
     ## is not overwritten?  /HB 2016-03-14
     enter <- bquote({
@@ -567,41 +567,36 @@ getExpression.Future <- function(future, local = future$local, stdout = future$s
     })
   }
 
-  ## Reset future strategies upon exit of future
+  ## Packages needed by the future
+  pkgs <- packages(future)
+  if (length(pkgs) > 0) {
+    if (debug) mdebugf("Packages needed by the future expression (n = %d): %s", length(pkgs), paste(sQuote(pkgs), collapse = ", "))
+  } else {
+    if (debug) mdebug("Packages needed by the future expression (n = 0): <none>")
+  }
+
+  ## Future strategies
   strategies <- plan("list")
   stop_if_not(length(strategies) >= 1L)
-  exit <- bquote({
-    ## covr: skip=2
-    .(exit)
-    future::plan(.(strategies), .cleanup = FALSE, .init = FALSE)
-  })
 
   ## Pass down the default or the remain set of future strategies?
   strategiesR <- strategies[-1]
-  ##  mdebug("Number of remaining strategies: %d\n", length(strategiesR))
+  ##  mdebugf("Number of remaining strategies: %d", length(strategiesR))
 
   ## Identify packages needed by the futures
-  pkgs <- NULL
   if (length(strategiesR) > 0L) {
     ## Identify package namespaces needed for strategies
-    pkgs <- lapply(strategiesR, FUN = environment)
-    pkgs <- lapply(pkgs, FUN = environmentName)
-    pkgs <- unique(unlist(pkgs, use.names = FALSE))
+    pkgsS <- lapply(strategiesR, FUN = environment)
+    pkgsS <- lapply(pkgsS, FUN = environmentName)
+    pkgsS <- unique(unlist(pkgsS, use.names = FALSE))
     ## CLEANUP: Only keep those that are loaded in the current session
-    pkgs <- intersect(pkgs, loadedNamespaces())
-    if (debug) mdebug("Packages needed by future strategies (n = %d): %s", length(pkgs), paste(sQuote(pkgs), collapse = ", "))
+    pkgsS <- intersect(pkgsS, loadedNamespaces())
+    if (debug) mdebugf("Packages needed by future strategies (n = %d): %s", length(pkgsS), paste(sQuote(pkgsS), collapse = ", "))
+    pkgs <- unique(c(pkgs, pkgsS))
   } else {
     if (debug) mdebug("Packages needed by future strategies (n = 0): <none>")
   }
 
-  pkgsF <- packages(future)
-  if (length(pkgsF) > 0) {
-    if (debug) mdebug("Packages needed by the future expression (n = %d): %s", length(pkgsF), paste(sQuote(pkgsF), collapse = ", "))
-    pkgs <- unique(c(pkgs, pkgsF))
-  } else {
-    if (debug) mdebug("Packages needed by the future expression (n = 0): <none>")
-  }
-
   ## Make sure to load and attach all package needed  
   if (length(pkgs) > 0L) {
     ## Sanity check by verifying packages can be loaded already here
@@ -629,22 +624,22 @@ getExpression.Future <- function(future, local = future$local, stdout = future$s
   }
 
   ## Make sure to set all nested future strategies needed
-  if (length(strategiesR) == 0L) {
-##    mdebug("Set plan('default') inside future")
-    ## Use default future strategy
-    enter <- bquote({
-      ## covr: skip=2
-      .(enter)
-      future::plan("default", .cleanup = FALSE, .init = FALSE)
-    })
-  } else {    
-    ## Pass down future strategies
-    enter <- bquote({
-      ## covr: skip=2
-      .(enter)
-      future::plan(.(strategiesR), .cleanup = FALSE, .init = FALSE)
-    })
-  } ## if (length(strategiesR) > 0L)
+  ## Use default future strategy?
+  if (length(strategiesR) == 0L) strategiesR <- "default"
+    
+  ## Pass down future strategies
+  enter <- bquote({
+    ## covr: skip=2
+    .(enter)
+    future::plan(.(strategiesR), .cleanup = FALSE, .init = FALSE)
+  })
+
+  ## Reset future strategies when done
+  exit <- bquote({
+    ## covr: skip=2
+    .(exit)
+    future::plan(.(strategies), .cleanup = FALSE, .init = FALSE)
+  })
 
   expr <- makeExpression(expr = future$expr, local = local, stdout = stdout, conditionClasses = conditionClasses, enter = enter, exit = exit, version = version)
   if (getOption("future.debug", FALSE)) mprint(expr)
