@@ -5,21 +5,24 @@
 #' the the value is \code{NULL}.
 #' 
 #' @param conditions A list of zero or more list elements each containing
-#' a captured [[base::condition]] and possibly more meta data such as the
+#' a captured \link[base:condition]{condition} and possibly more meta data such as the
 #' call stack and a timestamp.
 #'
 #' @param \ldots (optional) Additional named results to be returned.
 #' 
+#' @param started,finished \link[base:POSIXct]{POSIXct} timestamps when the evaluation of
+#' the future expression was started and finished.
+#'
 #' @param version The version format of the results.
 #'
 #' @return An object of class FutureResult.
 #'
 #' @details
-#' This function is only part of the _backend_ Future API.
-#' This function is _not_ part of the frontend Future API.
+#' This function is only part of the \emph{backend} Future API.
+#' This function is \emph{not} part of the frontend Future API.
 #'
 #' @section Note to developers:
-#' The FutureResult structure is _under development_ and may change at anytime,
+#' The FutureResult structure is \emph{under development} and may change at anytime,
 #' e.g. elements may be renamed or removed.  Because of this, please avoid
 #' accessing the elements directly in code.  Feel free to reach out if you need
 #' to do so in your code.
@@ -30,7 +33,7 @@
 #'
 #' @export
 #' @keywords internal
-FutureResult <- function(value = NULL, stdout = NULL, conditions = NULL, ..., version = "1.7") {
+FutureResult <- function(value = NULL, stdout = NULL, conditions = NULL, ..., started = .POSIXct(NA_real_), finished = Sys.time(), version = "1.7") {
   args <- list(...)
   if (length(args) > 0) {
     names <- names(args)
@@ -40,16 +43,16 @@ FutureResult <- function(value = NULL, stdout = NULL, conditions = NULL, ..., ve
       ))
     }
     ## DEPRECATED in future (>= 1.11.0)
-    if (!is.null(args$calls)) stop_if_not(is.list(args$calls))
-    if (!is.null(args$condition)) stop_if_not(inherits(args$condition, "error"))
+    if (!is.null(args[["calls"]])) stop_if_not(is.list(args[["calls"]]))
+    if (!is.null(args[["condition"]])) stop_if_not(inherits(args[["condition"]], "error"))
   }
 
   if (!is.null(stdout)) stopifnot(is.character(stdout))
   
   if (is.null(conditions)) {
     ## BACKWARD COMPATIBILITY: future (< 1.11.0)
-    if (!is.null(args$condition)) {
-      conditions <- list(list(condition=args$condition))
+    if (!is.null(args[["condition"]])) {
+      conditions <- list(list(condition=args[["condition"]]))
     }
   } else {
     stop_if_not(is.list(conditions))
@@ -57,8 +60,8 @@ FutureResult <- function(value = NULL, stdout = NULL, conditions = NULL, ..., ve
     ## Make sure that 'condition' is set, in case some pkgs use that
     for (kk in seq_along(conditions)) {
       c <- conditions[[kk]]
-      if (inherits(c$condition, "error")) {
-        args$condition <- c$condition
+      if (inherits(c[["condition"]], "error")) {
+        args[["condition"]] <- c[["condition"]]
 	break
       }
     }
@@ -69,6 +72,8 @@ FutureResult <- function(value = NULL, stdout = NULL, conditions = NULL, ..., ve
     stdout     = stdout,
     conditions = conditions,
     ...,
+    started    = started,
+    finished   = finished,
     version    = version
   ), class = "FutureResult")
 }
@@ -92,3 +97,19 @@ as.character.FutureResult <- function(x, ...) {
   info <- paste(info, collapse = "; ")
   sprintf("%s: %s", class(x)[1], info)
 }
+
+#' @rdname FutureResult
+#' @export
+#' @keywords internal
+print.FutureResult <- function(x, ...) {
+  s <- sprintf("%s:", class(x)[1])
+  s <- c(s, sprintf("value: %s", class(x[["value"]])))
+  s <- c(s, sprintf("stdout: %s", class(x[["stdout"]])))
+  conditions <- x[["conditions"]]
+  s <- c(s, sprintf("conditions: [n = %d] %s", length(conditions), paste(sapply(conditions, FUN = function(c) sQuote(class(c)[1])), collapse = ", ")))
+  t0 <- x[["started"]]
+  t1 <- x[["finished"]]
+  s <- c(s, sprintf("duration: %s (started %s)", format(t1-t0), t0))
+  s <- c(s, sprintf("version: %s", x[["version"]]))
+  cat(s, sep = "\n")
+}
