@@ -58,7 +58,7 @@ multisession <- function(expr, envir = parent.frame(), substitute = TRUE, lazy =
   ## that is, then use the current main R process.
   if (workers == 1L) {
     ## FIXME: How to handle argument 'persistent'? /HB 2016-03-19
-    return(sequential(expr, envir = envir, substitute = FALSE, lazy = TRUE, seed = seed, globals = globals, local = TRUE, label = label))
+    return(sequential(expr, envir = envir, substitute = FALSE, lazy = TRUE, seed = seed, globals = globals, local = TRUE, label = label, ...))
   }
 
   workers <- ClusterRegistry("start", workers = workers)
