@@ -12,7 +12,7 @@ print(y)
 stopifnot(y == 42L)
 
 
-message("*** future() w/ gc=TRUE ...")
+message("*** future() w/ gc = TRUE ...")
 
 f <- future(42L, gc = TRUE, lazy = TRUE)
 print(f)
@@ -20,7 +20,7 @@ y <- value(f)
 print(y)
 stopifnot(y == 42L)
 
-message("*** future() w/ gc=TRUE ... DONE")
+message("*** future() w/ gc = TRUE ... DONE")
 message("*** future() ... DONE")
 
 message("*** future() ...")
@@ -35,7 +35,7 @@ print(y)
 stopifnot(y == 42L)
 
 
-message("*** future() w/ gc=TRUE ...")
+message("*** future() w/ gc = TRUE ...")
 
 f <- future(42L, gc = TRUE, lazy = TRUE)
 print(f)
@@ -43,20 +43,20 @@ y <- value(f)
 print(y)
 stopifnot(y == 42L)
 
-message("*** future() w/ gc=TRUE ... DONE")
+message("*** future() w/ gc = TRUE ... DONE")
 
 
 message("*** future() - exceptions ...")
 
-res <- try(future(42L, evaluator=TRUE, lazy = TRUE))
-stopifnot(inherits(res, "try-error"))
+res <- tryCatch(future(42L, evaluator = TRUE, lazy = TRUE), error = identity)
+stopifnot(inherits(res, "error"))
 
-res <- try(future(42L, evaluator=function(...) TRUE, lazy = TRUE))
-stopifnot(inherits(res, "try-error"))
+res <- tryCatch(future(42L, evaluator = function(...) TRUE, lazy = TRUE), error = identity)
+stopifnot(inherits(res, "error"))
 
-target <- list(name="<unknown>", envir=new.env(), code="Yo!", exists=TRUE)
-res <- try(get_future(target, mustExist=TRUE))
-stopifnot(inherits(res, "try-error"))
+target <- list(name = "<unknown>", envir = new.env(), code = "Yo!", exists = TRUE)
+res <- tryCatch(get_future(target, mustExist = TRUE), error = identity)
+stopifnot(inherits(res, "error"))
 
 message("*** future() - exceptions ... DONE")
 
@@ -64,4 +64,3 @@ message("*** future() - exceptions ... DONE")
 message("*** future() ... DONE")
 
 source("incl/end.R")
-
